Limits

Struct Limits 

pub struct Limits {
    pub max_schema_len: usize,
    pub max_schema_id_len: usize,
    pub max_depth: usize,
    pub max_fields: usize,
    pub max_variants: usize,
    pub max_collection_len: usize,
    pub max_string_len: usize,
    pub max_bytes_len: usize,
    pub max_extension_len: usize,
    pub max_varint_bytes: usize,
}
Resource limits applied during schema validation and message encode/decode.

Fields

max_schema_len: usize

Maximum encoded schema size in bytes.

This limit is enforced symmetrically on decode and encode paths.

max_schema_id_len: usizemax_depth: usizemax_fields: usizemax_variants: usizemax_collection_len: usizemax_string_len: usizemax_bytes_len: usizemax_extension_len: usizemax_varint_bytes: usize